#!/bin/bash

my_exit() {
    exit $1
}

add_support_user(){
    useradd $s_user_support -s /bin/bash
    if [ $? -ne 0 ]; then
        echo "Failed to create user [$s_user_support]"
        my_exit 1
    fi
    echo $s_password_support | passwd $s_user_support --stdin
}

make_sudoer_entry_for_support_user(){
    local l_commands=$1

    if [ "X$l_commands" != "X" ]; then 
        echo "$s_user_support ALL=(ALL) NOPASSWD:$l_commands" >> $f_support_user_sudoers
    fi
}


add_sudoers_privileges(){
    # List of commands which are allowed for support user to execute as Root. 
    # As of now, All support user is allowed to execute all commands as super user.
    l_allowed_sudo_commands="ALL"

    # List of commands which are not allowed for support user to execute as Root. 
    # eg. if 'systemctl' command should not be allowed for support user then we can add that in following list as !<command>
    l_not_allowed_sudo_commands="!/bin/su"

    # List of commands which are specifically allowed for support user to execute as Root
    # This list contains a set of commands which are not allowed through $l_not_allowed_sudo_commands
    # eg. if 'systemctl' command is not allowed but we want to allow 'systemctl status *' then we can add it in the following list.
    l_specific_allowed_sudo_commands=""

    # define command aliases
    echo "Adding sudoers entry for [$s_user_support] in $f_support_user_sudoers file."
    
    make_sudoer_entry_for_support_user $l_allowed_sudo_commands
    make_sudoer_entry_for_support_user $l_not_allowed_sudo_commands
    make_sudoer_entry_for_support_user $l_specific_allowed_sudo_commands

}

add_fortisoar_auditd_rules(){
    
    echo "Adding audit rules for support user"

    s_support_userid=$(id -u $s_user_support)

    #audit rule is for logging all the 'execve' system calls performed by 'fortisoar_support' user. 
    #this logs are logged using key `$s_fortisoar_support_user_audit_key`
    echo "-a exit,always -F arch=b32 -F auid=$s_support_userid -S execve -k $s_fortisoar_support_user_audit_key"  >> $f_fortisoar_audit_rule

    echo "-a exit,always -F arch=b64 -F auid=$s_support_userid -S execve -k $s_fortisoar_support_user_audit_key"  >> $f_fortisoar_audit_rule

    # Load newly added rules for fortisoar_support user. 
    augenrules --load
}

set_access_control_list(){
    # List of commands which should not be allowed for support user to execute without sudo. 
    l_restricted_commands="/bin/psql /bin/openssl"

    # Restrict the access for commands for support user.  
    sudo setfacl -m u:$s_user_support:- $l_restricted_commands

}

allow_ssh_login(){
    # Allow ssh access to fortisoar_support user in the syste,
    echo "AllowGroups $s_user_support" >> $f_etc_sshd_config
    systemctl restart sshd
}

expire_password_for_support(){
    echo "Expiring the password for OS user [$s_user_support]"
    passwd --expire $s_user_support
}

init(){
    s_user_support="fortisoar_support"

    s_password_support="changeme"
    s_fortisoar_support_user_audit_key="fortisoar-support-user-audit"

    f_etc_sshd_config="/etc/ssh/sshd_config.d/fortisoar-support-user-login.conf"
    f_support_user_sudoers="/etc/sudoers.d/fortisoar-support-user"
    f_fortisoar_audit_rule="/etc/audit/rules.d/fortisoar-audit-rule.rules"

}

main(){
    add_support_user
    add_sudoers_privileges
    allow_ssh_login
    add_fortisoar_auditd_rules
    set_access_control_list
    expire_password_for_support
}

init
main

